@@ -26,11 +26,15 @@ from .teletypes.inline_query_result import InlineQueryResult
 api_url = 'https://api.telegram.org/bot{token}/{method}'
 
 
-def request(token, method, data=dict(), files=dict(), excpect=None):
+def request(token,
+            method,
+            data=dict(),
+            files=dict(),
+            excpect=None
+            ) -> Union[TelegramStructure, List[TelegramStructure]]:
     """Make a raw api request.
 
     Returns result as dataclass or list of dataclasses
-    Or dict if could not comprehend type
     """
     url = api_url.format(token=token, method=method)
 
